---
title: <span class="badge object-type-enum"></span> PercentChangeColorMode
---
# <span class="badge object-type-enum"></span> PercentChangeColorMode

TODO docs

## Definition

```python
class PercentChangeColorMode(enum.StrEnum):
    """
    TODO docs
    """

    STANDARD = "standard"
    INVERTED = "inverted"
    SAME_AS_VALUE = "same_as_value"
```
